DefaultFontWeight enum
Values
- w100 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w100, "100") - w200 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w200, "200") - w300 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w300, "300") - w400 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w400, "400") - w500 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w500, "500") - w600 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w600, "600") - w700 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w700, "700") - w800 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w800, "800") - w900 → const DefaultFontWeight
-
const DefaultFontWeight(FontWeight.w900, "900")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → FontWeight
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DefaultFontWeight> - A constant List of the values in this enum, in order of their declaration.