SimplifiedTextWidgetConfig class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

baseScreenWidth double
no setter
defaultColor Color
no setter
defaultFontWeight FontWeight
no setter
maxSizeMultiplier double
no setter
responsiveFonts bool
no setter

Static Methods

config({double? maxSizeMultiplier, double? baseScreenWidth, required bool responsiveFonts, DefaultFontWeight? defaultFontWeight, Color? defaultColor}) → void