Text45w800 class

Inheritance

Constructors

Text45w800(String text, {Key? key, Color? color, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, FontStyle? fontStyle, TextOverflow? overflow, int? maxLines, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, StrutStyle? strutStyle, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Paint? foreground, Paint? background, List<Shadow>? shadows, TextDecoration? decoration, double? decorationThickness, Color? decorationColor, TextDecorationStyle? decorationStyle, double? height, String? debugLabel, String? package, TextStyle? style, String? semanticsLabel})
const

Properties

background Paint?
final
color Color?
final
debugLabel String?
final
decoration TextDecoration?
final
decorationColor Color?
final
decorationStyle TextDecorationStyle?
final
decorationThickness double?
final
fontStyle FontStyle?
final
foreground Paint?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing double?
final
locale Locale?
final
maxLines int?
final
overflow TextOverflow?
final
package String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String?
final
shadows List<Shadow>?
final
softWrap bool?
final
strutStyle StrutStyle?
final
style TextStyle?
final
text String
final
textAlign TextAlign?
final
textBaseline TextBaseline?
final
textDirection TextDirection?
final
textHeightBehavior TextHeightBehavior?
final
textWidthBasis TextWidthBasis?
final
wordSpacing double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited